pub enum DelayCharacter {
Normal,
Analog,
}Expand description
Which of the two delay lines is running.
Both Stage manuals give the pair by name: “There are two different delay modes, the normal (‘non-analog’) mode, and the Analog Mode … In Analog Mode the pitch of any sounding repeats is altered if the tempo is changed.”
Variants
Implementations